package ACL2::Procesador;
use Exporter 'import';

#
# Postprocesador de demostraciones de ACL2
# Copyright (C) 2005-2008 Antonio García Domínguez
# $Id$
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

use 5.0006;
use warnings;
use strict;

use ACL2::Proyecto;

our $VERSION   = '1.184';
our @EXPORT_OK = qw(convert_to_xml);

my $lh = ACL2::Localizacion->get_handle();

=head1 NAME

ACL2::Procesador - Converts ACL2 proofs to XML

=head1 FUNCTIONS

This module exports a single function:

=head2 convert_to_xml($path_to_lisp_file)

Takes the path to the main (perhaps only) Lisp file in our project,
and produces a XML version of ACL2's output for that file. It takes
dependencies into account, and includes them in the final XML output,
so they can be followed through some more processing later.

Needs write access on all folders which use books, as it will use
temporary .out and .xml files to avoid redoing the same proofs
whenever possible. Will redo proofs automatically if the Lisp files
are more recent than these temporary files, or whenever any of the
.out or the .xml files is missing.

=cut

sub convert_to_xml {
    my ($path_to_lisp) = @_;

    my $project = new ACL2::Proyecto(ruta_lisp => $ARGV[0]);
    $project->actualizar;
    return $project->obtener_xml;
}

=head1 SYNOPSIS

  use ACL2::Procesador qw(convert_to_xml);
  my $path_to_lisp_file = "foo.lisp";
  print convert_to_xml($path_to_lisp_file);

=head1 AUTHOR

Antonio GarcE<iacute>a-DomE<iacute>nguez, C<< <nyoescape at gmail.com> >>

=head1 BUGS

Please report any bugs or feature requests to
C<nyoescape at gmail.com>, or through the web interface at
L<http://forja.rediris.es/projects/csl2-xmleye>.

=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc ACL2::Procesador

=head1 ACKNOWLEDGEMENTS

I'd like to thank my end of degree project supervisors, Francisco
Palomo Lozano and Inmaculada Medina Bulo, for their advice and
support.

=head1 COPYRIGHT & LICENSE

Copyright (C) 2005-2008 Antonio GarcE<iacute>a-DomE<iacute>nguez

This program is free software; you can redistribute it 
and/or modify it under the terms of the GNU General Public 
License as published by the Free Software Foundation; 
either version 2 of the License, or (at your option) any 
later version.

This program is distributed in the hope that it will be 
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE. See the GNU General Public License for more 
details.

You should have received a copy of the GNU General Public 
License along with this program; if not, write to the Free 
Software Foundation, Inc., 59 Temple Place, Suite 330, 
Boston, MA 02111-1307 USA

=cut

1; # End of ACL2::Procesador
__END__
